@@ -18,7 +18,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import unittest2
+import unittest
 import datetime
 from stalker import (Project, Repository, Status, StatusList, Task, TimeLog,
                      User)
@@ -26,7 +26,7 @@ from stalker.exceptions import OverBookedError, StatusError, \
     DependencyViolationError
 
 
-class TimeLogTester(unittest2.TestCase):
+class TimeLogTester(unittest.TestCase):
     """tests the TimeLog class
     """
 
@@ -478,7 +478,7 @@ class TimeLogTester(unittest2.TestCase):
         self.test_resource2.time_logs.append(time_log1)
 
 
-class TimeLogDBTestCase(unittest2.TestCase):
+class TimeLogDBTestCase(unittest.TestCase):
     """Tests database interaction of TimeLog instances
     """
 
@@ -820,13 +820,13 @@ class TimeLogDBTestCase(unittest2.TestCase):
             )
 
         self.assertEqual(
-            'It is not possible to create a TimeLog before %s, which violates '
-            'the dependency relation of "%s" to "%s"' % (
+            '\'It is not possible to create a TimeLog before %s, which '
+            'violates the dependency relation of "%s" to "%s"\'' % (
                 datetime.datetime(2014, 3, 25, 19, 0),
                 dep_task.name,
                 task.name
             ),
-            cm.exception.message
+            str(cm.exception)
         )
 
         # and creating a TimeLog after that is possible
@@ -876,13 +876,13 @@ class TimeLogDBTestCase(unittest2.TestCase):
             )
 
         self.assertEqual(
-            'It is not possible to create a TimeLog before %s, which violates '
-            'the dependency relation of "%s" to "%s"' % (
+            '\'It is not possible to create a TimeLog before %s, which '
+            'violates the dependency relation of "%s" to "%s"\'' % (
                 datetime.datetime(2014, 3, 16, 10, 0),
                 dep_task.name,
                 task.name
             ),
-            cm.exception.message
+            str(cm.exception)
         )
 
         # and creating a TimeLog after that is possible
